/*
 * Copyright 1991 Addison-Wesley Publishing Company
 *                (see the file "COPYRIGHTS" for details)
 */

/* includes */
#include <Xm/Xm.h>
#include <X11/Shell.h>
#include <Xm/RowColumn.h>

#include "IconWidget.h"

/* global definitions */

#define PROGRAM_CLASS "Icon"
#define ERROR_CLASS   "IconError"

#define NUM_ARGS 10

/* error definitions */

#define NErrCannotOpen "cannotOpen"
#define TErrMain       "Main"

/*************************/

static void PressMe (widget, client_data, call_data)
    Widget                widget;
    caddr_t               client_data;
    XmAnyCallbackStruct  *call_data;
{
    XBell (XtDisplay (widget), 100);
}

static void ToggleMe (widget, client_data, call_data)
    Widget                widget;
    caddr_t               client_data;
    XmAnyCallbackStruct  *call_data;
{
    unsigned char   shadow_type;
    Arg             args[NUM_ARGS];

    XtSetArg (args[0], XmNshadowType, &shadow_type);
    XtGetValues (widget, args, 1);

    XtSetArg (args[0], XmNshadowType,
              shadow_type == XmSHADOW_IN ? XmSHADOW_OUT : XmSHADOW_IN);
    XtSetValues (widget, args, 1);
}

static void CreateMainWindow (parent)
    Widget          parent;
{
    Widget          row, label, button, toggle;
    Arg             args[NUM_ARGS];
    XmString        face;

    XtSetArg (args[0], XmNorientation, XmHORIZONTAL);
    XtSetArg (args[1], XmNpacking, XmPACK_COLUMN);
    row = XtCreateManagedWidget ("row", xmRowColumnWidgetClass, parent,
                                 args, 2);

    face = XmStringLtoRCreate ("Label", XmSTRING_DEFAULT_CHARSET);
    XtSetArg (args[0], XmNlabelString, face);
    label = CreateIconLabel (row, "label", args, 1, 
               "editor.bm");
    XmStringFree (face);

    face = XmStringLtoRCreate ("PressMe", XmSTRING_DEFAULT_CHARSET);
    XtSetArg (args[0], XmNlabelString, face);
    button = CreateIconButton (row, "button", args, 1, 
               "editor.bm");
    XtAddCallback (button, XmNactivateCallback, PressMe, NULL);
    XmStringFree (face);

    face = XmStringLtoRCreate ("ToggleMe", XmSTRING_DEFAULT_CHARSET);
    XtSetArg (args[0], XmNlabelString, face);
    toggle = CreateIconButton (row, "toggle", args, 1, 
               "editor.bm");
    XtAddCallback (toggle, XmNactivateCallback, ToggleMe, NULL);
    XmStringFree (face);

}


/******************************/

void main (argc, argv)
    unsigned int    argc;
    char          **argv;
{
    Display        *display;
    XtAppContext    ac;
    Arg             args[NUM_ARGS];
    Widget          toplevel;

    /* init toolkit */
    XtToolkitInitialize();
    ac = XtCreateApplicationContext();
    display = XtOpenDisplay (
                  ac,          /* application context = default */
                  NULL,        /* use DISPLAY from environment  */
                  NULL,        /* use last of argv[0] as name   */
                  PROGRAM_CLASS,
                  NULL,        /* no add'tl cmd line options    */
                  0,           /* ditto                         */
                  &argc,
                  argv);        /* use and delete std options    */

    if (display == NULL)       /* necessary !                   */
        XtErrorMsg (
            NErrCannotOpen, TErrMain,  /* resource name         */
            ERROR_CLASS,               /* resource class        */
            "cannot open display",     /* default message       */
            NULL, NULL);               /* parameters            */

    /* create application shell */
    XtSetArg (args[0], XmNallowShellResize, True);
    toplevel = XtAppCreateShell (
                   NULL,               /* use same program name */
                   PROGRAM_CLASS,      /* repeat class param    */
                   applicationShellWidgetClass,
                   display,
                   args, 1);           /* argument list         */

    /* create main window */
    CreateMainWindow (toplevel);

    /* start loop */
    XtRealizeWidget (toplevel);
    XtAppMainLoop (ac);
}

