/*
 * Copyright 1991 Addison-Wesley Publishing Company
 *                (see the file "COPYRIGHTS" for details)
 */

#include <Xm/Xm.h>

/**************************************************************************
 * Struct for every class as central reference and node in the class tree 
 *************************************************************************/

#define MAX_SUBCLASSES 10
#define MAX_RESOURCES 40

typedef struct _classDoc {
    String            name;
    XmString          xm_name;
    struct _classDoc *super;
    struct _classDoc *subs[MAX_SUBCLASSES];
    int               no_subs;
    int               level;
    Boolean           file_read;
    /* The following fields are only valid when file-read is True */
    int               no_res;                    /* no of fields */
    String            res_name[MAX_RESOURCES],   /* field name */
                      res_text[MAX_RESOURCES];   /* description text */
    XmString          res_string[MAX_RESOURCES], /* name as XmString */
                      res_class[MAX_RESOURCES],  /* class name */
                      res_type[MAX_RESOURCES],   /* resource type */
                      res_default[MAX_RESOURCES];/* default value */
    int               res_access[MAX_RESOURCES], /* access flags */
                      res_range[MAX_RESOURCES]; 
    int               sections;   /* which additional sections are present */
} ClassDoc;

/* flag bits for access */

#define ACCESS_CREATE    1
#define ACCESS_WRITE     2
#define ACCESS_READ      4

/* possible values for range */

#define RANGE_CONSTRAINT 1
#define RANGE_SCROLLED   2
#define RANGE_SPECIAL    3

/* additional sections, flag bit is (1 << xxx_SEC)  */

#define DESCRIPTION_SEC  1
#define BEHAVIOUR_SEC    2
#define CALLBACK_SEC     3
#define TRANSLATION_SEC  4
#define TRAVERSAL_SEC    5
#define COLOR_SEC        6

/**************************************************************************
 * Procedures defined in helpbuf.c
 *************************************************************************/

/*
 * Shorthand utility for creating XmStrings
 */

XmString MakeXmString ();
  /* char    *string;   */

/*
 * Set the directory where to look for help files
 */
void SetHelpDir ();
  /* String  help_dir;   */

/*
 * Get the alphabetically sorted list of all class names as a
 * list of XmStrings
 */

XmString *GetClassNames ();
  /* int *no_class_names;    */

/*
 * Get the root node of the class tree (e.g. for traversal)
 */
 
ClassDoc *RootClass ();

/*
 * Fills the fields in the node structure if not already read
 */

void FillHelpInfo ();
  /* ClassDoc *doc;   */

/*
 * Read the text of an existing additional section into a buffer
 */

String ReadSection ();
  /* ClassDoc *doc;
     int section;     */

/*
 * Read a section in a specified file
 */

String ReadLongSection ();
  /* char  *file_ending;
     char  *section_name;   */

/*
 * Search the class tree for a node with a specific name
 */

ClassDoc *SearchClass ();
  /* XmString class_name;  */

/*
 * Find a list of matching fields for name fragment
 * - also store internal info about matches
 */

void FindMatchingFields ();
  /* String     fragment;
     XmString **match_list;
     int       *no_matches;    */

/*
 * Find info about member of current match list
 */

void LocateResource ();
  /* XmString    match_list_entry;
     ClassDoc  **which_doc;
     int        *which_entry;    */

/****************************** Error Messages ***************************/

#define ERROR_CLASS    "MhelpError"
#define WARN_CLASS     "MhelpWarning"

#define NErrCannotOpen "cannotOpen"
#define TErrMain       "Main"

#define NErrInternal   "internal"
#define TErrMenu       "Menu"
#define TErrChain      "Chain"

#define NErrFileOpen   "fileOpen"
#define TErrClassfile  "Classfile"
#define TErrSection    "Section"

#define NWarnNFnd      "notFound"
#define TWarnField     "Field"
#define TWarnFile      "File"



