/*
 * Copyright 1991 Addison-Wesley Publishing Company
 *                (see the file "COPYRIGHTS" for details)
 */

/* includes */
#include <Xm/Xm.h>
#include <X11/Shell.h>
#include <Xm/PushB.h>
#include <Xm/MessageB.h>

#include "StayUp.h"

/* global definitions */

#define PROGRAM_CLASS "StayUp"
#define ERROR_CLASS   "StayUpError"

#define NUM_ARGS 10

/* error definitions */

#define NErrCannotOpen "cannotOpen"
#define TErrMain       "Main"

/*************************/

static void StartDialog (widget, client_data, call_data)
    Widget                widget;
    caddr_t               client_data;
    XmAnyCallbackStruct  *call_data;
{
    XtManageChild ((Widget) client_data);
}

static void CreateMainWindow (parent)
    Widget          parent;
{
    Widget          button, dia;
    Arg             args[NUM_ARGS];
    XmString        face;

    face = XmStringLtoRCreate ("PressMe", XmSTRING_DEFAULT_CHARSET);
    XtSetArg (args[0], XmNlabelString, face);
    button = XtCreateManagedWidget (
                 "button",
                 xmPushButtonWidgetClass,
                 parent,
                 args, 1);
    XmStringFree (face);

    face = XmStringLtoRCreate ("Read Me", XmSTRING_DEFAULT_CHARSET);
    XtSetArg (args[0], XmNmessageString, face);
    XtSetArg (args[1], XmNautoUnmanage, False);
    dia = XmCreateMessageDialog (button, "dia", args, 2);
    XmStringFree (face);

    MakeDialogStayUp (dia);

    XtAddCallback (button, XmNactivateCallback, StartDialog, (caddr_t) dia);
}

/******************************/

void main (argc, argv)
    unsigned int    argc;
    char          **argv;
{
    Display        *display;
    XtAppContext ac;
    Widget          toplevel;
    Arg             args[NUM_ARGS];

    /* init toolkit */
    XtToolkitInitialize();
    ac = XtCreateApplicationContext();
    display = XtOpenDisplay (
                  ac,          /* application context = default */
                  NULL,        /* use DISPLAY from environment  */
                  NULL,        /* use last of argv[0] as name   */
                  PROGRAM_CLASS,
                  NULL,        /* no add'tl cmd line options    */
                  0,           /* ditto                         */
                  &argc,
                  argv);        /* use and delete std options    */

    if (display == NULL)       /* necessary !                   */
        XtErrorMsg (
            NErrCannotOpen, TErrMain,  /* resource name         */
            ERROR_CLASS,               /* resource class        */
            "cannot open display",     /* default message       */
            NULL, NULL);               /* parameters            */

    /* create application shell */
    XtSetArg (args[0], XmNallowShellResize, True);
    toplevel = XtAppCreateShell (
                   NULL,               /* use same program name */
                   PROGRAM_CLASS,      /* repeat class param    */
                   applicationShellWidgetClass,
                   display,
                   args, 1);           /* argument list         */

    /* create main window */
    CreateMainWindow (toplevel);

    /* start loop */
    XtRealizeWidget (toplevel);
    XtAppMainLoop (ac);
}

